piwrapper
=========

.. image:: https://img.shields.io/pypi/v/piwrapper.svg
    :target: https://pypi.python.org/pypi/piwrapper
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/kragniz/cookiecutter-pypackage-minimal.png
   :target: https://travis-ci.org/kragniz/cookiecutter-pypackage-minimal
   :alt: Latest Travis CI build status

Python connector access OSISOFT PI server via PI Web API.

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`piwrapper` was written by `Josh Chen <jcpythonlib@gmail.com>`_.
